@@ -1,3 +1,5 @@
+import json
+
 import pandas as pd
 from qm_spider import *
 from pyecharts.faker import Faker
@@ -11,8 +13,29 @@ from collections import Counter
 
 
 # 画图基础通用参数；
-class Pyecharts_Var:
-    def __init__(self, title, x_value, y_name, y_value, *args, subtitle='', is_symbol_show=False, line_width=2, is_show=False, color_list=['#00b088', '#f76b61', '#ffb55d', '#8470ff', '#00a2ff', '#ffe400', '#11d2c2', '#c263f9']):
+# class Pyecharts_Var:
+#     def __init__(self, title, x_value, y_name, y_value, *args, subtitle='', is_symbol_show=False, line_width=2, is_show=False, color_list=['#00b088', '#f76b61', '#ffb55d', '#8470ff', '#00a2ff', '#ffe400', '#11d2c2', '#c263f9']):
+#         self.subtitle = subtitle
+#         self.is_symbol_show = is_symbol_show
+#         self.line_width = line_width
+#         self.is_show = is_show
+#         self.color_list = color_list
+#         self.args = args
+#         self.title = title
+#         self.x_value = [str(i) for i in x_value]
+#         self.y_name = y_name
+#         self.y_value = [float(i) for i in y_value]
+#
+#     def render_to_png(self, c):
+#         make_snapshot(snapshot, c.render(), "./%s.png" %(self.title))
+
+# 折线图、面积图；
+class Line_Py:
+    def __init__(self, title, x_value, y_name, y_value, *args, pos_top='top', is_zoom=False, is_orient='horizontal', legend_icon='roundRect', subtitle='', is_symbol_show=False, line_width=2, is_show=False, color_list=['#00b088', '#f76b61', '#ffb55d', '#8470ff', '#00a2ff', '#ffe400', '#11d2c2', '#c263f9']):
+        self.pos_top = pos_top
+        self.legend_icon = legend_icon
+        self.is_zoom = is_zoom
+        self.is_orient = is_orient
         self.subtitle = subtitle
         self.is_symbol_show = is_symbol_show
         self.line_width = line_width
@@ -27,13 +50,6 @@ class Pyecharts_Var:
     def render_to_png(self, c):
         make_snapshot(snapshot, c.render(), "./%s.png" %(self.title))
 
-# 折线图、面积图；
-class Line_Py(Pyecharts_Var):
-    def __init__(self, title, x_value, y_name, y_value, *args, pos_top='bottom', legend_icon='roundRect'):
-        Pyecharts_Var.__init__(self, title, x_value, y_name, y_value, *args)
-        self.pos_top = pos_top
-        self.legend_icon = legend_icon
-
     def line_render_air(self):
         c = Line()
         c.add_xaxis(self.x_value)
@@ -48,6 +64,12 @@ class Line_Py(Pyecharts_Var):
             title_opts=opts.TitleOpts(title=self.title, subtitle=self.subtitle),
             tooltip_opts=opts.TooltipOpts(trigger="axis"),
             legend_opts=opts.LegendOpts(pos_left="center", pos_top=self.pos_top, legend_icon=self.legend_icon),
+            datazoom_opts=opts.DataZoomOpts(
+                is_show=self.is_zoom,
+                range_start=0,
+                range_end=100,
+                orient=self.is_orient  # 表示横轴可滑动还是纵轴可滑动；
+            ),
             yaxis_opts=opts.AxisOpts(
                 type_="value",
                 max_='dataMax',
@@ -76,7 +98,6 @@ class Line_Py(Pyecharts_Var):
         )
         if len(self.args) > 0:
             for num in range(len(self.args[0])):
-                print(2)
                 c.add_yaxis(
                     series_name = self.args[0][num],
                     y_axis = self.args[1][num],
@@ -88,8 +109,8 @@ class Line_Py(Pyecharts_Var):
         return c
 
     def line_render_qimai(self):
-        # c = Line(init_opts=opts.InitOpts(width="1200px", height="400px"))
-        c = Line()
+        c = Line(init_opts=opts.InitOpts(width="1200px", height="400px"))
+        # c = Line()
         c.add_xaxis(self.x_value)
         c.add_yaxis(
             series_name=self.y_name,
@@ -109,7 +130,8 @@ class Line_Py(Pyecharts_Var):
                 ),
             ),
             tooltip_opts=opts.TooltipOpts(trigger="axis"),
-            legend_opts=opts.LegendOpts(pos_left="center", pos_top=self.pos_top, legend_icon='circle'),
+            # legend_opts=opts.LegendOpts(pos_left="center", pos_top=self.pos_top, legend_icon='circle'),
+            legend_opts=opts.LegendOpts(pos_left="center", pos_top='bottom', legend_icon='circle'),
             yaxis_opts=opts.AxisOpts(
                 type_="value",
                 max_='dataMax',
@@ -214,12 +236,27 @@ class Line_Py(Pyecharts_Var):
         return c
 
 # 柱状图；
-class Bar_Py(Pyecharts_Var):
-    def __init__(self, title, x_value, y_name, y_value, reversal_axis=True, pos_top='bottom', legend_icon='roundRect'):
-        Pyecharts_Var.__init__(self, title, x_value, y_name, y_value)
+class Bar_Py:
+    def __init__(self, title, x_value, y_name, y_value, *args, reversal_axis=True, pos_top='top', is_zoom=False, is_orient='horizontal', legend_icon='roundRect', subtitle='', is_show=False):
         self.reversal_axis = reversal_axis
         self.pos_top = pos_top
         self.legend_icon = legend_icon
+        self.is_zoom = is_zoom
+        self.is_orient = is_orient
+        self.subtitle = subtitle
+        self.is_show = is_show
+        self.args = args
+        self.title = title
+        self.x_value = [str(i) for i in x_value]
+        self.y_name = y_name
+        self.y_value = [float(i) for i in y_value]
+        # , is_symbol_show = False, line_width = 2, color_list = ['#00b088', '#f76b61', '#ffb55d', '#8470ff', '#00a2ff', '#ffe400', '#11d2c2', '#c263f9']
+        # self.color_list = color_list
+        # self.is_symbol_show = is_symbol_show
+        # self.line_width = line_width
+
+    def render_to_png(self, c):
+        make_snapshot(snapshot, c.render(), "./%s.png" %(self.title))
 
     def bar_render_general(self):
         c = Bar()
@@ -253,6 +290,12 @@ class Bar_Py(Pyecharts_Var):
             title_opts=opts.TitleOpts(title=self.title, subtitle=self.subtitle),
             tooltip_opts=opts.TooltipOpts(trigger="axis"),
             legend_opts=opts.LegendOpts(pos_left="center", pos_top=self.pos_top, legend_icon=self.legend_icon),
+            datazoom_opts=opts.DataZoomOpts(
+                is_show=self.is_zoom,
+                range_start=0,
+                range_end=100,
+                orient=self.is_orient  # 表示横轴可滑动还是纵轴可滑动；
+            ),
             yaxis_opts=opts.AxisOpts(
                 type_="value",
                 max_='dataMax',
@@ -279,8 +322,15 @@ class Bar_Py(Pyecharts_Var):
                 ),
             )
         )
-        for agr_data in self.args:
-            c.add_yaxis(agr_data[0], agr_data[1])
+        if len(self.args) > 0:
+            for num in range(len(self.args[0])):
+                c.add_yaxis(
+                    series_name = self.args[0][num],
+                    y_axis = self.args[1][num],
+                    label_opts=opts.LabelOpts(is_show=self.is_show)
+                )
+        # for agr_data in self.args:
+        #     c.add_yaxis(agr_data[0], agr_data[1])
         return c
 
 # 人物/事件关系图；
@@ -414,6 +464,9 @@ class WordCloud_Py:
         self.pos_top = pos_top
         self.args = args
 
+    def render_to_png(self, c):
+        make_snapshot(snapshot, c.render(), "./%s.png" %(self.title))
+
     def jieba_cut(self, length_num=0):
         if type(self.args[0]) == list:
             word_data = ''.join(self.args[0])
